@@ -795,10 +795,6 @@ class cube : public std::enable_shared_from_this<cube> {
 
     void write_single_chunk_netcdf(chunkid_t id, std::string path, uint8_t compression_level = 0);
 
-
-
-
-
     /**
      * @brief Writes a data cube as a collection of PNG files
      *
@@ -832,13 +828,6 @@ class cube : public std::enable_shared_from_this<cube> {
                               bool drop_empty_slices = false,
                               std::shared_ptr<chunk_processor> p = config::instance()->get_default_chunk_processor());
 
-
-
-
-
-
-
-
     /**
      * Get the cube's bands
      * @return all bands of the cube object as band_collection
@@ -895,6 +884,15 @@ class cube : public std::enable_shared_from_this<cube> {
      * @brief List of cube instances that take this object as input (successors)
      */
     std::vector<std::weak_ptr<cube>> _succ;
+
+
+    /**
+     * @brief Optimization flag defining whether pixel values depend on pixel values located somewhere else
+     */
+    bool _optim_is_local; // TODO
+    bool _optim_is_chunk_local;  // TODO
+    bool _optim_reccomend_cache_input; // TODO
+
 };
 
 }  // namespace gdalcubes
